import{_ as c,u as v,E as b,a as S,S as V}from"./StreamlitVue.3lsU-Xtu.js";/* empty css                               */import{d as u,r as m,o as _,c as x,a as C,q as h,w as l,m as y,s as p,t as i,b as k}from"./runtime-dom.esm-bundler.W8VUoGb5.js";/* empty css                               */const D=u({__name:"DsfrRange",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(s,{expose:o}){o(),v();const a=s,e=m(a.args.modelValue??a.args.min??0),r=m(e.value);let t=null;function n(){e.value!==r.value&&(r.value=e.value,S.setComponentValue(e.value))}function f(){t&&(clearTimeout(t),t=null),t=setTimeout(n,200)}const d={props:a,value:e,lastValue:r,get timeoutUpdate(){return t},set timeoutUpdate(g){t=g},setComponentValue:n,onUpdateModelValue:f,get DsfrRange(){return b}};return Object.defineProperty(d,"__isScriptSetup",{enumerable:!1,value:!0}),d}}),U={class:"component"};function R(s,o,a,e,r,t){return _(),x("div",U,[C(e.DsfrRange,y(e.props.args,{disabled:e.props.disabled||e.props.args.disabled,modelValue:e.value,"onUpdate:modelValue":[o[0]||(o[0]=n=>e.value=n),e.onUpdateModelValue]}),h({_:2},[e.props.args.label?{name:"label",fn:l(()=>[p(i(e.props.args.label),1)]),key:"0"}:void 0,e.props.args.hint?{name:"hint",fn:l(()=>[p(i(e.props.args.hint),1)]),key:"1"}:void 0,e.props.args.messages?{name:"messages",fn:l(()=>[p(i(e.props.args.messages),1)]),key:"2"}:void 0]),1040,["disabled","modelValue"])])}const B=c(D,[["render",R],["__scopeId","data-v-81302ce6"]]),w=u({__name:"DsfrRange",setup(s,{expose:o}){o();const a={StreamlitComponent:V,Component:B};return Object.defineProperty(a,"__isScriptSetup",{enumerable:!1,value:!0}),a}});function E(s,o,a,e,r,t){return _(),k(e.StreamlitComponent,{component:e.Component,"client:load":""})}const N=c(w,[["render",E]]);export{N as default};
