import{_ as n,u as _,e as i,S as u}from"./StreamlitVue.3lsU-Xtu.js";/* empty css                                 */import{d as s,o as a,c as m,a as d,n as l,g as f,b as P}from"./runtime-dom.esm-bundler.W8VUoGb5.js";/* empty css                               */const S=s({__name:"DsfrPicture",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(o,{expose:t}){t(),_();const e={props:o,get DsfrPicture(){return i}};return Object.defineProperty(e,"__isScriptSetup",{enumerable:!1,value:!0}),e}}),b={class:"component"};function x(o,t,r,e,c,p){return a(),m("div",b,[d(e.DsfrPicture,l(f(e.props.args)),null,16)])}const $=n(S,[["render",x],["__scopeId","data-v-dcb3aa53"]]),g=s({__name:"DsfrPicture",setup(o,{expose:t}){t();const r={StreamlitComponent:u,Component:$};return Object.defineProperty(r,"__isScriptSetup",{enumerable:!1,value:!0}),r}});function h(o,t,r,e,c,p){return a(),P(e.StreamlitComponent,{component:e.Component,"client:load":""})}const k=n(g,[["render",h]]);export{k as default};
