.dsfr-component[data-v-7ffeaddc]{display:contents}.dsfr-component[data-v-7ffeaddc] .fr-btn>span{display:contents}.dsfr-component[data-icon-only][data-v-7ffeaddc] .fr-btn{padding-inline:.5rem!important}.dsfr-component[data-icon-only][data-v-7ffeaddc] .fr-btn iconify-icon{font-size:1.5em}
