import{_ as n,u as _,h as d,S as i}from"./StreamlitVue.3lsU-Xtu.js";import{d as s,o as a,c as m,a as l,n as u,g as f,b as g}from"./runtime-dom.esm-bundler.W8VUoGb5.js";/* empty css                               */const B=s({__name:"DsfrBadge",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(o,{expose:r}){r(),_();const e={props:o,get DsfrBadge(){return d}};return Object.defineProperty(e,"__isScriptSetup",{enumerable:!1,value:!0}),e}}),S={class:"component"};function h(o,r,t,e,p,c){return a(),m("div",S,[l(e.DsfrBadge,u(f(e.props.args)),null,16)])}const b=n(B,[["render",h]]),x=s({__name:"DsfrBadge",setup(o,{expose:r}){r();const t={StreamlitComponent:i,Component:b};return Object.defineProperty(t,"__isScriptSetup",{enumerable:!1,value:!0}),t}});function $(o,r,t,e,p,c){return a(),g(e.StreamlitComponent,{component:e.Component,"client:load":""})}const P=n(x,[["render",$]]);export{P as default};
