import{_ as n,u as _,f as l,S as i}from"./StreamlitVue.3lsU-Xtu.js";import{d as s,o as a,c as m,a as f,n as u,g as d,b as S}from"./runtime-dom.esm-bundler.W8VUoGb5.js";/* empty css                               */const b=s({__name:"DsfrAlert",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(o,{expose:r}){r(),_();const e={props:o,get DsfrAlert(){return l}};return Object.defineProperty(e,"__isScriptSetup",{enumerable:!1,value:!0}),e}}),x={class:"component"};function $(o,r,t,e,p,c){return a(),m("div",x,[f(e.DsfrAlert,u(d(e.props.args)),null,16)])}const g=n(b,[["render",$]]),h=s({__name:"DsfrAlert",setup(o,{expose:r}){r();const t={StreamlitComponent:i,Component:g};return Object.defineProperty(t,"__isScriptSetup",{enumerable:!1,value:!0}),t}});function A(o,r,t,e,p,c){return a(),S(e.StreamlitComponent,{component:e.Component,"client:load":""})}const B=n(h,[["render",A]]);export{B as default};
