import{_ as St,A as Tt}from"./StreamlitVue.3lsU-Xtu.js";/* empty css                                */import{d as Et,k as Mt,o as _e,c as rt,a as Ft,w as Rt,b as Pt,l as st,t as Nt,m as Lt}from"./runtime-dom.esm-bundler.W8VUoGb5.js";/**
* (c) Iconify
*
* For the full copyright and license information, please view the license.txt
* files at https://github.com/iconify/iconify
*
* Licensed under MIT.
*
* @license MIT
* @version 2.0.0
*/(function(){const F=Object.freeze({left:0,top:0,width:16,height:16}),I=Object.freeze({rotate:0,vFlip:!1,hFlip:!1}),j=Object.freeze({...F,...I}),v=Object.freeze({...j,body:"",hidden:!1}),R=Object.freeze({width:null,height:null}),P=Object.freeze({...R,...I}),N=/[\s,]+/,L={...P,preserveAspectRatio:""};function C(e){const t={...L},n=(o,c)=>e.getAttribute(o)||c;var r;return t.width=n("width",null),t.height=n("height",null),t.rotate=function(o,c=0){const a=o.replace(/^-?[0-9.]*/,"");function i(s){for(;s<0;)s+=4;return s%4}if(a===""){const s=parseInt(o);return isNaN(s)?0:i(s)}if(a!==o){let s=0;switch(a){case"%":s=25;break;case"deg":s=90}if(s){let l=parseFloat(o.slice(0,o.length-a.length));return isNaN(l)?0:(l/=s,l%1==0?i(l):0)}}return c}(n("rotate","")),r=t,n("flip","").split(N).forEach(o=>{switch(o.trim()){case"horizontal":r.hFlip=!0;break;case"vertical":r.vFlip=!0}}),t.preserveAspectRatio=n("preserveAspectRatio",n("preserveaspectratio","")),t}const S=/^[a-z0-9]+(-[a-z0-9]+)*$/,B=(e,t,n,r="")=>{const o=e.split(":");if(e.slice(0,1)==="@"){if(o.length<2||o.length>3)return null;r=o.shift().slice(1)}if(o.length>3||!o.length)return null;if(o.length>1){const i=o.pop(),s=o.pop(),l={provider:o.length>0?o[0]:r,prefix:s,name:i};return t&&!H(l)?null:l}const c=o[0],a=c.split("-");if(a.length>1){const i={provider:r,prefix:a.shift(),name:a.join("-")};return t&&!H(i)?null:i}if(n&&r===""){const i={provider:r,prefix:"",name:c};return t&&!H(i,n)?null:i}return null},H=(e,t)=>!!e&&!(e.provider!==""&&!e.provider.match(S)||!(t&&e.prefix===""||e.prefix.match(S))||!e.name.match(S));function xe(e,t){const n=function(r,o){const c={};!r.hFlip!=!o.hFlip&&(c.hFlip=!0),!r.vFlip!=!o.vFlip&&(c.vFlip=!0);const a=((r.rotate||0)+(o.rotate||0))%4;return a&&(c.rotate=a),c}(e,t);for(const r in v)r in I?r in e&&!(r in n)&&(n[r]=I[r]):r in t?n[r]=t[r]:r in e&&(n[r]=e[r]);return n}function ct(e,t,n){const r=e.icons,o=e.aliases||Object.create(null);let c={};function a(i){c=xe(r[i]||o[i],c)}return a(t),n.forEach(a),xe(e,c)}function we(e,t){const n=[];if(typeof e!="object"||typeof e.icons!="object")return n;e.not_found instanceof Array&&e.not_found.forEach(o=>{t(o,null),n.push(o)});const r=function(o,c){const a=o.icons,i=o.aliases||Object.create(null),s=Object.create(null);return(c||Object.keys(a).concat(Object.keys(i))).forEach(function l(u){if(a[u])return s[u]=[];if(!(u in s)){s[u]=null;const f=i[u]&&i[u].parent,d=f&&l(f);d&&(s[u]=[f].concat(d))}return s[u]}),s}(e);for(const o in r){const c=r[o];c&&(t(o,ct(e,o,c)),n.push(o))}return n}const at={provider:"",aliases:{},not_found:{},...F};function Y(e,t){for(const n in t)if(n in e&&typeof e[n]!=typeof t[n])return!1;return!0}function ke(e){if(typeof e!="object"||e===null)return null;const t=e;if(typeof t.prefix!="string"||!e.icons||typeof e.icons!="object"||!Y(e,at))return null;const n=t.icons;for(const o in n){const c=n[o];if(!o.match(S)||typeof c.body!="string"||!Y(c,v))return null}const r=t.aliases||Object.create(null);for(const o in r){const c=r[o],a=c.parent;if(!o.match(S)||typeof a!="string"||!n[a]&&!r[a]||!Y(c,v))return null}return t}const J=Object.create(null);function A(e,t){const n=J[e]||(J[e]=Object.create(null));return n[t]||(n[t]=function(r,o){return{provider:r,prefix:o,icons:Object.create(null),missing:new Set}}(e,t))}function Z(e,t){return ke(t)?we(t,(n,r)=>{r?e.icons[n]=r:e.missing.add(n)}):[]}function lt(e,t){let n=[];return(typeof e=="string"?[e]:Object.keys(J)).forEach(r=>{(typeof r=="string"&&typeof t=="string"?[t]:Object.keys(J[r]||{})).forEach(o=>{const c=A(r,o);n=n.concat(Object.keys(c.icons).map(a=>(r!==""?"@"+r+":":"")+o+":"+a))})}),n}let z=!1;function Oe(e){return typeof e=="boolean"&&(z=e),z}function D(e){const t=typeof e=="string"?B(e,!0,z):e;if(t){const n=A(t.provider,t.prefix),r=t.name;return n.icons[r]||(n.missing.has(r)?null:void 0)}}function je(e,t){const n=B(e,!0,z);return n?function(r,o,c){try{if(typeof c.body=="string")return r.icons[o]={...c},!0}catch{}return!1}(A(n.provider,n.prefix),n.name,t):!1}function Ce(e,t){if(typeof e!="object")return!1;if(typeof t!="string"&&(t=e.provider||""),z&&!t&&!e.prefix){let r=!1;return ke(e)&&(e.prefix="",we(e,(o,c)=>{c&&je(o,c)&&(r=!0)})),r}const n=e.prefix;return H({provider:t,prefix:n,name:"a"})?!!Z(A(t,n),e):!1}function Ae(e){return!!D(e)}function ut(e){const t=D(e);return t?{...j,...t}:null}function Ie(e,t){e.forEach(n=>{const r=n.loaderCallbacks;r&&(n.loaderCallbacks=r.filter(o=>o.id!==t))})}let ft=0;const $=Object.create(null);function Se(e,t){$[e]=t}function ee(e){return $[e]||$[""]}var dt={resources:[],index:0,timeout:2e3,rotate:750,random:!1,dataAfterTimeout:!1};function ht(e,t,n,r){const o=e.resources.length,c=e.random?Math.floor(Math.random()*o):e.index;let a;if(e.random){let p=e.resources.slice(0);for(a=[];p.length>1;){const x=Math.floor(Math.random()*p.length);a.push(p[x]),p=p.slice(0,x).concat(p.slice(x+1))}a=a.concat(p)}else a=e.resources.slice(c).concat(e.resources.slice(0,c));const i=Date.now();let s,l="pending",u=0,f=null,d=[],h=[];function m(){f&&(clearTimeout(f),f=null)}function y(){l==="pending"&&(l="aborted"),m(),d.forEach(p=>{p.status==="pending"&&(p.status="aborted")}),d=[]}function g(p,x){x&&(h=[]),typeof p=="function"&&h.push(p)}function _(){l="failed",h.forEach(p=>{p(void 0,s)})}function w(){d.forEach(p=>{p.status==="pending"&&(p.status="aborted")}),d=[]}function b(){if(l!=="pending")return;m();const p=a.shift();if(p===void 0)return d.length?void(f=setTimeout(()=>{m(),l==="pending"&&(w(),_())},e.timeout)):void _();const x={status:"pending",resource:p,callback:(be,me)=>{(function(U,M,E){const k=M!=="success";switch(d=d.filter(O=>O!==U),l){case"pending":break;case"failed":if(k||!e.dataAfterTimeout)return;break;default:return}if(M==="abort")return s=E,void _();if(k)return s=E,void(d.length||(a.length?b():_()));if(m(),w(),!e.random){const O=e.resources.indexOf(U.resource);O!==-1&&O!==e.index&&(e.index=O)}l="completed",h.forEach(O=>{O(E)})})(x,be,me)}};d.push(x),u++,f=setTimeout(b,e.rotate),n(p,t,x.callback)}return typeof r=="function"&&h.push(r),setTimeout(b),function(){return{startTime:i,payload:t,status:l,queriesSent:u,queriesPending:d.length,subscribe:g,abort:y}}}function Te(e){const t={...dt,...e};let n=[];function r(){n=n.filter(o=>o().status==="pending")}return{query:function(o,c,a){const i=ht(t,o,c,(s,l)=>{r(),a&&a(s,l)});return n.push(i),i},find:function(o){return n.find(c=>o(c))||null},setIndex:o=>{t.index=o},getIndex:()=>t.index,cleanup:r}}function te(e){let t;if(typeof e.resources=="string")t=[e.resources];else if(t=e.resources,!(t instanceof Array&&t.length))return null;return{resources:t,path:e.path||"/",maxURL:e.maxURL||500,rotate:e.rotate||750,timeout:e.timeout||5e3,random:e.random===!0,index:e.index||0,dataAfterTimeout:e.dataAfterTimeout!==!1}}const V=Object.create(null),G=["https://api.simplesvg.com","https://api.unisvg.com"],ne=[];for(;G.length>0;)G.length===1||Math.random()>.5?ne.push(G.shift()):ne.push(G.pop());function Ee(e,t){const n=te(t);return n!==null&&(V[e]=n,!0)}function K(e){return V[e]}function pt(){return Object.keys(V)}function Me(){}V[""]=te({resources:["https://api.iconify.design"].concat(ne)});const oe=Object.create(null);function Fe(e,t,n){let r,o;if(typeof e=="string"){const c=ee(e);if(!c)return n(void 0,424),Me;o=c.send;const a=function(i){if(!oe[i]){const s=K(i);if(!s)return;const l={config:s,redundancy:Te(s)};oe[i]=l}return oe[i]}(e);a&&(r=a.redundancy)}else{const c=te(e);if(c){r=Te(c);const a=ee(e.resources?e.resources[0]:"");a&&(o=a.send)}}return r&&o?r.query(t,o,n)().abort:(n(void 0,424),Me)}const Re="iconify2",Q="iconify",Pe=Q+"-count",Ne=Q+"-version",Le=36e5,gt=168,bt=50;function ie(e,t){try{return e.getItem(t)}catch{}}function re(e,t,n){try{return e.setItem(t,n),!0}catch{}}function Be(e,t){try{e.removeItem(t)}catch{}}function se(e,t){return re(e,Pe,t.toString())}function ce(e){return parseInt(ie(e,Pe))||0}const T={local:!0,session:!0},ze={local:new Set,session:new Set};let ae=!1,W=typeof window>"u"?{}:window;function De(e){const t=e+"Storage";try{if(W&&W[t]&&typeof W[t].length=="number")return W[t]}catch{}T[e]=!1}function Qe(e,t){const n=De(e);if(!n)return;const r=ie(n,Ne);if(r!==Re){if(r){const i=ce(n);for(let s=0;s<i;s++)Be(n,Q+s.toString())}return re(n,Ne,Re),void se(n,0)}const o=Math.floor(Date.now()/Le)-gt,c=i=>{const s=Q+i.toString(),l=ie(n,s);if(typeof l=="string"){try{const u=JSON.parse(l);if(typeof u=="object"&&typeof u.cached=="number"&&u.cached>o&&typeof u.provider=="string"&&typeof u.data=="object"&&typeof u.data.prefix=="string"&&t(u,i))return!0}catch{}Be(n,s)}};let a=ce(n);for(let i=a-1;i>=0;i--)c(i)||(i===a-1?(a--,se(n,a)):ze[e].add(i))}function qe(){if(!ae){ae=!0;for(const e in T)Qe(e,t=>{const n=t.data,r=A(t.provider,n.prefix);if(!Z(r,n).length)return!1;const o=n.lastModified||-1;return r.lastModifiedCached=r.lastModifiedCached?Math.min(r.lastModifiedCached,o):o,!0})}}function mt(e,t){function n(r){let o;if(!T[r]||!(o=De(r)))return;const c=ze[r];let a;if(c.size)c.delete(a=Array.from(c).shift());else if(a=ce(o),a>=bt||!se(o,a+1))return;const i={cached:Math.floor(Date.now()/Le),provider:e.provider,data:t};return re(o,Q+a.toString(),JSON.stringify(i))}ae||qe(),t.lastModified&&!function(r,o){const c=r.lastModifiedCached;if(c&&c>=o)return c===o;if(r.lastModifiedCached=o,c)for(const a in T)Qe(a,i=>{const s=i.data;return i.provider!==r.provider||s.prefix!==r.prefix||s.lastModified===o});return!0}(e,t.lastModified)||Object.keys(t.icons).length&&(t.not_found&&delete(t=Object.assign({},t)).not_found,n("local")||n("session"))}function Ue(){}function vt(e){e.iconsLoaderFlag||(e.iconsLoaderFlag=!0,setTimeout(()=>{e.iconsLoaderFlag=!1,function(t){t.pendingCallbacksFlag||(t.pendingCallbacksFlag=!0,setTimeout(()=>{t.pendingCallbacksFlag=!1;const n=t.loaderCallbacks?t.loaderCallbacks.slice(0):[];if(!n.length)return;let r=!1;const o=t.provider,c=t.prefix;n.forEach(a=>{const i=a.icons,s=i.pending.length;i.pending=i.pending.filter(l=>{if(l.prefix!==c)return!0;const u=l.name;if(t.icons[u])i.loaded.push({provider:o,prefix:c,name:u});else{if(!t.missing.has(u))return r=!0,!0;i.missing.push({provider:o,prefix:c,name:u})}return!1}),i.pending.length!==s&&(r||Ie([t],a.id),a.callback(i.loaded.slice(0),i.missing.slice(0),i.pending.slice(0),a.abort))})}))}(e)}))}const le=(e,t)=>{const n=function(s,l=!0,u=!1){const f=[];return s.forEach(d=>{const h=typeof d=="string"?B(d,l,u):d;h&&f.push(h)}),f}(e,!0,Oe()),r=function(s){const l={loaded:[],missing:[],pending:[]},u=Object.create(null);s.sort((d,h)=>d.provider!==h.provider?d.provider.localeCompare(h.provider):d.prefix!==h.prefix?d.prefix.localeCompare(h.prefix):d.name.localeCompare(h.name));let f={provider:"",prefix:"",name:""};return s.forEach(d=>{if(f.name===d.name&&f.prefix===d.prefix&&f.provider===d.provider)return;f=d;const h=d.provider,m=d.prefix,y=d.name,g=u[h]||(u[h]=Object.create(null)),_=g[m]||(g[m]=A(h,m));let w;w=y in _.icons?l.loaded:m===""||_.missing.has(y)?l.missing:l.pending;const b={provider:h,prefix:m,name:y};w.push(b)}),l}(n);if(!r.pending.length){let s=!0;return t&&setTimeout(()=>{s&&t(r.loaded,r.missing,r.pending,Ue)}),()=>{s=!1}}const o=Object.create(null),c=[];let a,i;return r.pending.forEach(s=>{const{provider:l,prefix:u}=s;if(u===i&&l===a)return;a=l,i=u,c.push(A(l,u));const f=o[l]||(o[l]=Object.create(null));f[u]||(f[u]=[])}),r.pending.forEach(s=>{const{provider:l,prefix:u,name:f}=s,d=A(l,u),h=d.pendingIcons||(d.pendingIcons=new Set);h.has(f)||(h.add(f),o[l][u].push(f))}),c.forEach(s=>{const{provider:l,prefix:u}=s;o[l][u].length&&function(f,d){f.iconsToLoad?f.iconsToLoad=f.iconsToLoad.concat(d).sort():f.iconsToLoad=d,f.iconsQueueFlag||(f.iconsQueueFlag=!0,setTimeout(()=>{f.iconsQueueFlag=!1;const{provider:h,prefix:m}=f,y=f.iconsToLoad;let g;delete f.iconsToLoad,y&&(g=ee(h))&&g.prepare(h,m,y).forEach(_=>{Fe(h,_,w=>{if(typeof w!="object")_.icons.forEach(b=>{f.missing.add(b)});else try{const b=Z(f,w);if(!b.length)return;const p=f.pendingIcons;p&&b.forEach(x=>{p.delete(x)}),mt(f,w)}catch(b){console.error(b)}vt(f)})})}))}(s,o[l][u])}),t?function(s,l,u){const f=ft++,d=Ie.bind(null,u,f);if(!l.pending.length)return d;const h={id:f,icons:l,callback:s,abort:d};return u.forEach(m=>{(m.loaderCallbacks||(m.loaderCallbacks=[])).push(h)}),d}(t,r,c):Ue},yt=e=>new Promise((t,n)=>{const r=typeof e=="string"?B(e,!0):e;r?le([r||e],o=>{if(o.length&&r){const c=D(r);if(c)return void t({...j,...c})}n(e)}):n(e)});function _t(e,t){const n=typeof e=="string"?B(e,!0,!0):null;if(!n){const c=function(a){try{const i=typeof a=="string"?JSON.parse(a):a;if(typeof i.body=="string")return{...i}}catch{}}(e);return{value:e,data:c}}const r=D(n);if(r!==void 0||!n.prefix)return{value:e,name:n,data:r};const o=le([n],()=>t(e,n,D(n)));return{value:e,name:n,loading:o}}function ue(e){return e.hasAttribute("inline")}let He=!1;try{He=navigator.vendor.indexOf("Apple")===0}catch{}const xt=/(-?[0-9.]*[0-9]+[0-9.]*)/g,wt=/^-?[0-9.]*[0-9]+[0-9.]*$/g;function fe(e,t,n){if(t===1)return e;if(n=n||100,typeof e=="number")return Math.ceil(e*t*n)/n;if(typeof e!="string")return e;const r=e.split(xt);if(r===null||!r.length)return e;const o=[];let c=r.shift(),a=wt.test(c);for(;;){if(a){const i=parseFloat(c);isNaN(i)?o.push(c):o.push(Math.ceil(i*t*n)/n)}else o.push(c);if(c=r.shift(),c===void 0)return o.join("");a=!a}}const kt=e=>e==="unset"||e==="undefined"||e==="none";function Je(e,t){const n={...j,...e},r={...P,...t},o={left:n.left,top:n.top,width:n.width,height:n.height};let c=n.body;[n,r].forEach(y=>{const g=[],_=y.hFlip,w=y.vFlip;let b,p=y.rotate;switch(_?w?p+=2:(g.push("translate("+(o.width+o.left).toString()+" "+(0-o.top).toString()+")"),g.push("scale(-1 1)"),o.top=o.left=0):w&&(g.push("translate("+(0-o.left).toString()+" "+(o.height+o.top).toString()+")"),g.push("scale(1 -1)"),o.top=o.left=0),p<0&&(p-=4*Math.floor(p/4)),p%=4,p){case 1:b=o.height/2+o.top,g.unshift("rotate(90 "+b.toString()+" "+b.toString()+")");break;case 2:g.unshift("rotate(180 "+(o.width/2+o.left).toString()+" "+(o.height/2+o.top).toString()+")");break;case 3:b=o.width/2+o.left,g.unshift("rotate(-90 "+b.toString()+" "+b.toString()+")")}p%2==1&&(o.left!==o.top&&(b=o.left,o.left=o.top,o.top=b),o.width!==o.height&&(b=o.width,o.width=o.height,o.height=b)),g.length&&(c=function(x,be,me){const U=function(k,O="defs"){let nt="";const ve=k.indexOf("<"+O);for(;ve>=0;){const ot=k.indexOf(">",ve),ye=k.indexOf("</"+O);if(ot===-1||ye===-1)break;const it=k.indexOf(">",ye);if(it===-1)break;nt+=k.slice(ot+1,ye).trim(),k=k.slice(0,ve).trim()+k.slice(it+1)}return{defs:nt,content:k}}(x);return M=U.defs,E=be+U.content+me,M?"<defs>"+M+"</defs>"+E:E;var M,E}(c,'<g transform="'+g.join(" ")+'">',"</g>"))});const a=r.width,i=r.height,s=o.width,l=o.height;let u,f;a===null?(f=i===null?"1em":i==="auto"?l:i,u=fe(f,s/l)):(u=a==="auto"?s:a,f=i===null?fe(u,l/s):i==="auto"?l:i);const d={},h=(y,g)=>{kt(g)||(d[y]=g.toString())};h("width",u),h("height",f);const m=[o.left,o.top,s,l];return d.viewBox=m.join(" "),{attributes:d,viewBox:m,body:c}}function de(e,t){let n=e.indexOf("xlink:")===-1?"":' xmlns:xlink="http://www.w3.org/1999/xlink"';for(const r in t)n+=" "+r+'="'+t[r]+'"';return'<svg xmlns="http://www.w3.org/2000/svg"'+n+">"+e+"</svg>"}function Ve(e){return'url("'+function(t){return"data:image/svg+xml,"+function(n){return n.replace(/"/g,"'").replace(/%/g,"%25").replace(/#/g,"%23").replace(/</g,"%3C").replace(/>/g,"%3E").replace(/\s+/g," ")}(t)}(e)+'")'}let X=(()=>{let e;try{if(e=fetch,typeof e=="function")return e}catch{}})();function Ot(e){X=e}function jt(){return X}const Ct={prepare:(e,t,n)=>{const r=[],o=function(s,l){const u=K(s);if(!u)return 0;let f;if(u.maxURL){let d=0;u.resources.forEach(m=>{d=Math.max(d,m.length)});const h=l+".json?icons=";f=u.maxURL-d-u.path.length-h.length}else f=0;return f}(e,t),c="icons";let a={type:c,provider:e,prefix:t,icons:[]},i=0;return n.forEach((s,l)=>{i+=s.length+1,i>=o&&l>0&&(r.push(a),a={type:c,provider:e,prefix:t,icons:[]},i=s.length),a.icons.push(s)}),r.push(a),r},send:(e,t,n)=>{if(!X)return void n("abort",424);let r=function(c){if(typeof c=="string"){const a=K(c);if(a)return a.path}return"/"}(t.provider);switch(t.type){case"icons":{const c=t.prefix,a=t.icons.join(",");r+=c+".json?"+new URLSearchParams({icons:a}).toString();break}case"custom":{const c=t.uri;r+=c.slice(0,1)==="/"?c.slice(1):c;break}default:return void n("abort",400)}let o=503;X(e+r).then(c=>{const a=c.status;if(a===200)return o=501,c.json();setTimeout(()=>{n(function(i){return i===404}(a)?"abort":"next",a)})}).then(c=>{setTimeout(typeof c=="object"&&c!==null?()=>{n("success",c)}:()=>{c===404?n("abort",c):n("next",o)})}).catch(()=>{n("next",o)})}};function Ge(e,t){switch(e){case"local":case"session":T[e]=t;break;case"all":for(const n in T)T[n]=t}}const he="data-style";let Ke="";function At(e){Ke=e}function We(e,t){let n=Array.from(e.childNodes).find(r=>r.hasAttribute&&r.hasAttribute(he));n||(n=document.createElement("style"),n.setAttribute(he,he),e.appendChild(n)),n.textContent=":host{display:inline-block;vertical-align:"+(t?"-0.125em":"0")+"}span,svg{display:block}"+Ke}const pe={"background-color":"currentColor"},Xe={"background-color":"transparent"},Ye={image:"var(--svg)",repeat:"no-repeat",size:"100% 100%"},Ze={"-webkit-mask":pe,mask:pe,background:Xe};for(const e in Ze){const t=Ze[e];for(const n in Ye)t[e+"-"+n]=Ye[n]}function $e(e){return e?e+(e.match(/^[-0-9.]+$/)?"px":""):"inherit"}let q;function It(e){return q===void 0&&function(){try{q=window.trustedTypes.createPolicy("iconify",{createHTML:t=>t})}catch{q=null}}(),q?q.createHTML(e):e}function ge(e){return Array.from(e.childNodes).find(t=>{const n=t.tagName&&t.tagName.toUpperCase();return n==="SPAN"||n==="SVG"})}function et(e,t){const n=t.icon.data,r=t.customisations,o=Je(n,r);r.preserveAspectRatio&&(o.attributes.preserveAspectRatio=r.preserveAspectRatio);const c=t.renderedMode;let a;c==="svg"?a=function(s){const l=document.createElement("span"),u=s.attributes;let f="";u.width||(f="width: inherit;"),u.height||(f+="height: inherit;"),f&&(u.style=f);const d=de(s.body,u);return l.innerHTML=It(d),l.firstChild}(o):a=function(s,l,u){const f=document.createElement("span");let d=s.body;d.indexOf("<a")!==-1&&(d+="<!-- "+Date.now()+" -->");const h=s.attributes,m=Ve(de(d,{...h,width:l.width+"",height:l.height+""})),y=f.style,g={"--svg":m,width:$e(h.width),height:$e(h.height),...u?pe:Xe};for(const _ in g)y.setProperty(_,g[_]);return f}(o,{...j,...n},c==="mask");const i=ge(e);i?a.tagName==="SPAN"&&i.tagName===a.tagName?i.setAttribute("style",a.getAttribute("style")):e.replaceChild(a,i):e.appendChild(a)}function tt(e,t,n){return{rendered:!1,inline:t,icon:e,lastRender:n&&(n.rendered?n:n.lastRender)}}(function(e="iconify-icon"){let t,n;try{t=window.customElements,n=window.HTMLElement}catch{return}if(!t||!n)return;const r=t.get(e);if(r)return r;const o=["icon","mode","inline","observe","width","height","rotate","flip"],c=class extends n{_shadowRoot;_initialised=!1;_state;_checkQueued=!1;_connected=!1;_observer=null;_visible=!0;constructor(){super();const i=this._shadowRoot=this.attachShadow({mode:"open"}),s=ue(this);We(i,s),this._state=tt({value:""},s),this._queueCheck()}connectedCallback(){this._connected=!0,this.startObserver()}disconnectedCallback(){this._connected=!1,this.stopObserver()}static get observedAttributes(){return o.slice(0)}attributeChangedCallback(i){switch(i){case"inline":{const s=ue(this),l=this._state;s!==l.inline&&(l.inline=s,We(this._shadowRoot,s));break}case"observer":this.observer?this.startObserver():this.stopObserver();break;default:this._queueCheck()}}get icon(){const i=this.getAttribute("icon");if(i&&i.slice(0,1)==="{")try{return JSON.parse(i)}catch{}return i}set icon(i){typeof i=="object"&&(i=JSON.stringify(i)),this.setAttribute("icon",i)}get inline(){return ue(this)}set inline(i){i?this.setAttribute("inline","true"):this.removeAttribute("inline")}get observer(){return this.hasAttribute("observer")}set observer(i){i?this.setAttribute("observer","true"):this.removeAttribute("observer")}restartAnimation(){const i=this._state;if(i.rendered){const s=this._shadowRoot;if(i.renderedMode==="svg")try{return void s.lastChild.setCurrentTime(0)}catch{}et(s,i)}}get status(){const i=this._state;return i.rendered?"rendered":i.icon.data===null?"failed":"loading"}_queueCheck(){this._checkQueued||(this._checkQueued=!0,setTimeout(()=>{this._check()}))}_check(){if(!this._checkQueued)return;this._checkQueued=!1;const i=this._state,s=this.getAttribute("icon");if(s!==i.icon.value)return void this._iconChanged(s);if(!i.rendered||!this._visible)return;const l=this.getAttribute("mode"),u=C(this);i.attrMode===l&&!function(f,d){for(const h in L)if(f[h]!==d[h])return!0;return!1}(i.customisations,u)&&ge(this._shadowRoot)||this._renderIcon(i.icon,u,l)}_iconChanged(i){const s=_t(i,(l,u,f)=>{const d=this._state;if(d.rendered||this.getAttribute("icon")!==l)return;const h={value:l,name:u,data:f};h.data?this._gotIconData(h):d.icon=h});s.data?this._gotIconData(s):this._state=tt(s,this._state.inline,this._state)}_forceRender(){if(this._visible)this._queueCheck();else{const i=ge(this._shadowRoot);i&&this._shadowRoot.removeChild(i)}}_gotIconData(i){this._checkQueued=!1,this._renderIcon(i,C(this),this.getAttribute("mode"))}_renderIcon(i,s,l){const u=function(d,h){switch(h){case"svg":case"bg":case"mask":return h}return h==="style"||!He&&d.indexOf("<a")!==-1?d.indexOf("currentColor")===-1?"bg":"mask":"svg"}(i.data.body,l),f=this._state.inline;et(this._shadowRoot,this._state={rendered:!0,icon:i,inline:f,customisations:s,attrMode:l,renderedMode:u})}startObserver(){if(!this._observer)try{this._observer=new IntersectionObserver(i=>{const s=i.some(l=>l.isIntersecting);s!==this._visible&&(this._visible=s,this._forceRender())}),this._observer.observe(this)}catch{if(this._observer){try{this._observer.disconnect()}catch{}this._observer=null}}}stopObserver(){this._observer&&(this._observer.disconnect(),this._observer=null,this._visible=!0,this._connected&&this._forceRender())}};o.forEach(i=>{i in c.prototype||Object.defineProperty(c.prototype,i,{get:function(){return this.getAttribute(i)},set:function(s){s!==null?this.setAttribute(i,s):this.removeAttribute(i)}})});const a=function(){let i;Se("",Ct),Oe(!0);try{i=window}catch{}if(i){if(qe(),i.IconifyPreload!==void 0){const s=i.IconifyPreload,l="Invalid IconifyPreload syntax.";typeof s=="object"&&s!==null&&(s instanceof Array?s:[s]).forEach(u=>{try{(typeof u!="object"||u===null||u instanceof Array||typeof u.icons!="object"||typeof u.prefix!="string"||!Ce(u))&&console.error(l)}catch{console.error(l)}})}if(i.IconifyProviders!==void 0){const s=i.IconifyProviders;if(typeof s=="object"&&s!==null)for(const l in s){const u="IconifyProviders["+l+"] is invalid.";try{const f=s[l];if(typeof f!="object"||!f||f.resources===void 0)continue;Ee(l,f)||console.error(u)}catch{console.error(u)}}}}return{enableCache:s=>Ge(s,!0),disableCache:s=>Ge(s,!1),iconLoaded:Ae,iconExists:Ae,getIcon:ut,listIcons:lt,addIcon:je,addCollection:Ce,calculateSize:fe,buildIcon:Je,iconToHTML:de,svgToURL:Ve,loadIcons:le,loadIcon:yt,addAPIProvider:Ee,appendCustomStyle:At,_api:{getAPIConfig:K,setAPIModule:Se,sendAPIQuery:Fe,setFetch:Ot,getFetch:jt,listAPIProviders:pt}}}();for(const i in a)c[i]=c.prototype[i]=a[i];t.define(e,c)})()})();const Bt=Et({__name:"DsfrButton",props:{label:{},secondary:{type:Boolean},tertiary:{type:Boolean},disabled:{type:Boolean},icon:{},iconOnly:{type:Boolean},iconRight:{type:Boolean},noOutline:{type:Boolean},size:{},link:{},copy:{}},emits:["click"],setup(F,{expose:I,emit:j}){I();const v=F,R=j;function P(C){v.link?window.open(v.link,"_blank")?.focus():v.copy&&navigator.clipboard.writeText(v.copy).catch(S=>{console.error("Failed to copy:",S)}),R("click",C)}function N(C){return C&&C.replace("-",":")}const L={props:v,emit:R,onClick:P,iconToIconify:N,get DsfrButton(){return Tt}};return Object.defineProperty(L,"__isScriptSetup",{enumerable:!1,value:!0}),L}}),zt=["data-icon-only"],Dt={key:1};function Qt(F,I,j,v,R,P){const N=Mt("iconify-icon");return _e(),rt("div",{class:"dsfr-component","data-icon-only":v.props.iconOnly?"":void 0},[Ft(v.DsfrButton,Lt(v.props,{label:void 0,icon:void 0,iconOnly:void 0,onClick:v.onClick}),{default:Rt(()=>[v.props.icon?(_e(),Pt(N,{key:0,icon:v.iconToIconify(v.props.icon)},null,8,["icon"])):st("",!0),v.props.iconOnly?st("",!0):(_e(),rt("span",Dt,Nt(v.props.label),1))]),_:1},16)],8,zt)}const Jt=St(Bt,[["render",Qt],["__scopeId","data-v-7ffeaddc"]]);export{Jt as D};
